not_found_fallback

Function not_found_fallback 

pub fn not_found_fallback(
    template: Option<String>,
) -> impl Fn(Request<Body>) -> Pin<Box<dyn Future<Output = Response<Body>> + Send>> + Clone + Send + Sync + 'static
Build an axum fallback handler that renders the configured 404 template. Used when not_found_template is set but slash_redirect is OffApp::build skips the slash redirect path and installs this directly.