Form

Struct Form 

pub struct Form<T>(pub T);
URL encoded extractor and response.

As extractor

If used as an extractor, Form will deserialize form data from the request, specifically:

  • If the request has a method of GET or HEAD, the form data will be read from the query string (same as with Query)
  • If the request has a different method, the form will be read from the body of the request. It must have a content-type of application/x-www-form-urlencoded for this to work. If you want to parse multipart/form-data request bodies, use Multipart instead.

This matches how HTML forms are sent by browsers by default. In both cases, the inner type T must implement [serde::Deserialize].

⚠️ Since parsing form data might require consuming the request body, the Form extractor must be last if there are multiple extractors in a handler. See “the order of extractors”

use axum::Form;
use serde::Deserialize;

#[derive(Deserialize)]
struct SignUp {
    username: String,
    password: String,
}

async fn accept_form(Form(sign_up): Form<SignUp>) {
    // ...
}

As response

Form can also be used to encode any type that implements [serde::Serialize] as application/x-www-form-urlencoded

use axum::Form;
use serde::Serialize;

#[derive(Serialize)]
struct Payload {
    value: String,
}

async fn handler() -> Form<Payload> {
    Form(Payload { value: "foo".to_owned() })
}

Tuple Fields

0: T